==> OwnersManual.1.0.tar.gz: OwnersManual/function.admin_view_manual.php <==
<?php

#-------------------------------------------------------------------------
# Module: OwnersManual
# Author: Wishbone <wayne@teamwishbone.com>
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#-------------------------------------------------------------------------
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#-------------------------------------------------------------------------
#END_LICENSE

if (!isset($gCms)) exit;

if (! $this->CheckPermission('View OwnersManual') && ! $this->CheckPermission('Edit OwnersManual')) {
  echo $this->ShowErrors($this->Lang('accessdenied'));
}

$db =& $this->GetDb();
$man_id = 1;

$query = "SELECT * FROM {$this->MANUAL_TABLE}
          WHERE man_id='$man_id'
          LIMIT 1";
$dbresult =& $db->Execute($query);
$row = $dbresult->FetchRow();

if ($row['man_smarty']) {
  $smarty->assign('man_content', $row['man_content']);
  echo $this->ProcessTemplate('admin_view_manual.tpl');
} else {
  echo($row['man_content']);
}
?>

==> OwnersManual-1.0.2.tar.gz: OwnersManual/function.admin_view_manual.php <==
<?php

#-------------------------------------------------------------------------
# Module: OwnersManual
# Author: Wishbone <wayne@teamwishbone.com>
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#-------------------------------------------------------------------------
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#-------------------------------------------------------------------------
#END_LICENSE

if (!isset($gCms)) exit;

if (! $this->CheckPermission('View OwnersManual') && ! $this->CheckPermission('Edit OwnersManual')) {
  echo $this->ShowErrors($this->Lang('accessdenied'));
}

$db =& $this->GetDb();
$man_id = 1;

$query = "SELECT * FROM {$this->MANUAL_TABLE}
          WHERE man_id='$man_id'
          LIMIT 1";
$dbresult =& $db->Execute($query);
$row = $dbresult->FetchRow();

$smarty->assign('man_smarty', $row['man_smarty']);
$smarty->assign('man_content', $row['man_content']);
echo $this->ProcessTemplate('admin_view_manual.tpl');
?>
